"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Joi = require("joi");
const CompatibilityActionProcessor_1 = require("./CompatibilityActionProcessor");
/**
 * Context variables resolver
 */
class ActionHandler {
    /**
     * Get working directory
     * @returns {string} with alternative wd to use
     * @returns {null} when original working directory should be used
     */
    getWorkingDirectory() {
        return null;
    }
    /**
     * Get action processor (should create new instance upon call)
     * @return {ActionProcessor}
     */
    getProcessor(options, context, snapshot, parameters) {
        const compatibilityProcessor = new CompatibilityActionProcessor_1.CompatibilityActionProcessor(options, context, snapshot, parameters);
        compatibilityProcessor.actionHandler = this;
        return compatibilityProcessor;
    }
    /**
     * Validate options before processing.
     * Should throw exception on error.
     * @param options
     * @param {IContext} context
     * @param {ActionSnapshot} snapshot
     * @param parameters
     * @returns {Promise<void>}
     * Get action processor (should create new instance upon call)
     * @deprecated
     */
    validate(options, context, snapshot, parameters) {
        return __awaiter(this, void 0, void 0, function* () {
            const schema = this.getValidationSchema();
            /* istanbul ignore next */
            if (schema) {
                const result = Joi.validate(options, schema);
                if (result.error) {
                    throw new Error(result.error.details.map(d => d.message).join('\n'));
                }
            }
        });
    }
    /**
     * Get Joi schema to validate options with
     * @deprecated
     */
    getValidationSchema() {
        return null;
    }
    /**
     * Check if handler should be actually executed
     * @param options
     * @param {IContext} context
     * @param {ActionSnapshot} snapshot
     * @param {IDelegatedParameters} parameters
     * @deprecated
     */
    isShouldExecute(options, context, snapshot, parameters) {
        return __awaiter(this, void 0, void 0, function* () {
            return true;
        });
    }
    /**
     * Execute handler
     * @param options
     * @param {IContext} context
     * @param {ActionSnapshot} snapshot
     * @param {IDelegatedParameters} parameters
     * @deprecated
     */
    execute(options, context, snapshot, parameters) {
        return __awaiter(this, void 0, void 0, function* () {
            throw new Error('ActionHandler.execute() method is deprecated.');
        });
    }
}
exports.ActionHandler = ActionHandler;
//# sourceMappingURL=ActionHandler.js.map