"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../../models");
const Joi = require("joi");
const BaseExecutableActionProcessor_1 = require("./BaseExecutableActionProcessor");
const schemas_1 = require("../../schemas");
class ExecActionProcessor extends BaseExecutableActionProcessor_1.BaseExecutableActionProcessor {
    /**
     * @inheritdoc
     */
    getValidationSchema() {
        return ExecActionProcessor.validationSchema;
    }
    /**
     * @inheritdoc
     */
    execute() {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.exec(this.options.command, this.options.args, this.options.wd, this.options.options);
            yield this.storeResult(this.options.assignResultTo, this.options.pushResultTo, result);
        });
    }
}
exports.ExecActionProcessor = ExecActionProcessor;
ExecActionProcessor.validationSchema = Joi.object({
    command: Joi.string()
        .min(1)
        .required(),
    args: Joi.array().items(Joi.alternatives(Joi.string().min(1), Joi.number())),
    options: Joi.object({
        stdout: Joi.boolean(),
        stderr: Joi.boolean(),
        verbose: Joi.boolean(),
    }),
    assignResultTo: schemas_1.FBL_ASSIGN_TO_SCHEMA,
    pushResultTo: schemas_1.FBL_ASSIGN_TO_SCHEMA,
    wd: Joi.string().min(1),
})
    .required()
    .options({ abortEarly: true });
class ExecActionHandler extends models_1.ActionHandler {
    /**
     * @inheritdoc
     */
    getMetadata() {
        return ExecActionHandler.metadata;
    }
    /**
     * @inheritdoc
     */
    getProcessor(options, context, snapshot, parameters) {
        return new ExecActionProcessor(options, context, snapshot, parameters);
    }
}
exports.ExecActionHandler = ExecActionHandler;
ExecActionHandler.metadata = {
    id: 'com.fireblink.fbl.exec',
    aliases: ['fbl.exec', 'exec'],
};
//# sourceMappingURL=ExecActionHandler.js.map