"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../../models");
const Joi = require("joi");
const util_1 = require("util");
const fs_1 = require("fs");
const BaseExecutableActionProcessor_1 = require("./BaseExecutableActionProcessor");
const typedi_1 = require("typedi");
const services_1 = require("../../services");
const schemas_1 = require("../../schemas");
class SheelActionProcessor extends BaseExecutableActionProcessor_1.BaseExecutableActionProcessor {
    /**
     * @inheritdoc
     */
    getValidationSchema() {
        return SheelActionProcessor.validationSchema;
    }
    /**
     * @inheritdoc
     */
    execute() {
        return __awaiter(this, void 0, void 0, function* () {
            const file = yield typedi_1.Container.get(services_1.TempPathsRegistry).createTempFile();
            yield util_1.promisify(fs_1.writeFile)(file, this.options.script, 'utf8');
            const result = yield this.exec(this.options.executable, [file], this.options.wd, this.options.options);
            yield this.storeResult(this.options.assignResultTo, this.options.pushResultTo, result);
        });
    }
}
exports.SheelActionProcessor = SheelActionProcessor;
SheelActionProcessor.validationSchema = Joi.object({
    executable: Joi.string()
        .min(1)
        .required(),
    script: Joi.string()
        .min(1)
        .required(),
    options: Joi.object({
        stdout: Joi.boolean(),
        stderr: Joi.boolean(),
        verbose: Joi.boolean(),
    }),
    assignResultTo: schemas_1.FBL_ASSIGN_TO_SCHEMA,
    pushResultTo: schemas_1.FBL_PUSH_TO_SCHEMA,
    wd: Joi.string().min(1),
})
    .required()
    .options({ abortEarly: true });
class ShellActionHandler extends models_1.ActionHandler {
    /**
     * @inheritdoc
     */
    getMetadata() {
        return ShellActionHandler.metadata;
    }
    /**
     * @inheritdoc
     */
    getProcessor(options, context, snapshot, parameters) {
        return new SheelActionProcessor(options, context, snapshot, parameters);
    }
}
exports.ShellActionHandler = ShellActionHandler;
ShellActionHandler.metadata = {
    id: 'com.fireblink.fbl.shell',
    aliases: ['fbl.shell', 'shell'],
};
//# sourceMappingURL=ShellActionHandler.js.map