"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../../models");
const Joi = require("joi");
const services_1 = require("../../services");
const typedi_1 = require("typedi");
const schemas_1 = require("../../schemas");
const BaseFlowActionProcessor_1 = require("./BaseFlowActionProcessor");
class ForEachFlowActionProcessor extends BaseFlowActionProcessor_1.BaseFlowActionProcessor {
    /**
     * @inheritdoc
     */
    getValidationSchema() {
        return ForEachFlowActionProcessor.validationSchema;
    }
    /**
     * @inheritdoc
     */
    validate() {
        const _super = Object.create(null, {
            validate: { get: () => super.validate }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const flowService = typedi_1.Container.get(services_1.FlowService);
            this.options.of = yield flowService.resolveOptionsWithNoHandlerCheck(this.context.ejsTemplateDelimiters.local, this.options.of, this.context, this.snapshot, this.parameters, false);
            if (this.options.async) {
                this.options.async = yield flowService.resolveOptionsWithNoHandlerCheck(this.context.ejsTemplateDelimiters.local, this.options.async, this.context, this.snapshot, this.parameters, false);
            }
            yield _super.validate.call(this);
        });
    }
    /**
     * @inheritdoc
     */
    execute() {
        return __awaiter(this, void 0, void 0, function* () {
            const flowService = typedi_1.Container.get(services_1.FlowService);
            const promises = [];
            const snapshots = [];
            const isArray = Array.isArray(this.options.of);
            const iterable = isArray ? this.options.of : Object.keys(this.options.of);
            for (let i = 0; i < iterable.length; i++) {
                const iteration = {
                    index: i,
                };
                if (isArray) {
                    iteration.value = iterable[i];
                }
                else {
                    iteration.value = this.options.of[iterable[i]];
                    iteration.key = iterable[i];
                }
                const actionParameters = this.getParameters(this.options.shareParameters, iteration);
                if (this.options.async) {
                    promises.push(((p) => __awaiter(this, void 0, void 0, function* () {
                        snapshots[p.iteration.index] = yield flowService.executeAction(this.snapshot.source, this.snapshot.wd, this.options.action, this.context, p, this.snapshot);
                    }))(actionParameters));
                }
                else {
                    const result = (snapshots[i] = yield flowService.executeAction(this.snapshot.source, this.snapshot.wd, this.options.action, this.context, actionParameters, this.snapshot));
                    if (!result.successful) {
                        break;
                    }
                }
            }
            yield Promise.all(promises);
            // register snapshots in the order of their presence
            snapshots.forEach(childSnapshot => {
                this.snapshot.registerChildActionSnapshot(childSnapshot);
            });
        });
    }
}
exports.ForEachFlowActionProcessor = ForEachFlowActionProcessor;
ForEachFlowActionProcessor.validationSchema = Joi.object({
    shareParameters: Joi.boolean(),
    of: Joi.alternatives(Joi.object(), Joi.array()).required(),
    action: schemas_1.FBL_ACTION_SCHEMA,
    async: Joi.boolean(),
})
    .required()
    .options({ abortEarly: true });
class ForEachFlowActionHandler extends models_1.ActionHandler {
    /**
     * @inheritdoc
     */
    getMetadata() {
        return ForEachFlowActionHandler.metadata;
    }
    /**
     * @inheritdoc
     */
    getProcessor(options, context, snapshot, parameters) {
        return new ForEachFlowActionProcessor(options, context, snapshot, parameters);
    }
}
exports.ForEachFlowActionHandler = ForEachFlowActionHandler;
ForEachFlowActionHandler.metadata = {
    id: 'com.fireblink.fbl.flow.foreach',
    aliases: ['fbl.flow.foreach', 'flow.foreach', 'foreach', 'each'],
    // We don't want to process options as a template to avoid unexpected behaviour inside nested actions
    skipTemplateProcessing: true,
};
//# sourceMappingURL=ForEachFlowActionHandler.js.map