"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Joi = require("joi");
const models_1 = require("../../models");
const services_1 = require("../../services");
const typedi_1 = require("typedi");
const schemas_1 = require("../../schemas");
const BaseFlowActionProcessor_1 = require("./BaseFlowActionProcessor");
class RepeatFlowActionProcessor extends BaseFlowActionProcessor_1.BaseFlowActionProcessor {
    /**
     * @inheritdoc
     */
    getValidationSchema() {
        return RepeatFlowActionProcessor.validationSchema;
    }
    /**
     * @inheritdoc
     */
    execute() {
        return __awaiter(this, void 0, void 0, function* () {
            const flowService = typedi_1.Container.get(services_1.FlowService);
            const promises = [];
            const snapshots = [];
            for (let i = 0; i < this.options.times; i++) {
                const iterationParams = this.getParameters(this.options.shareParameters, { index: i });
                if (this.options.async) {
                    promises.push(((p) => __awaiter(this, void 0, void 0, function* () {
                        snapshots[p.iteration.index] = yield flowService.executeAction(this.snapshot.source, this.snapshot.wd, this.options.action, this.context, p, this.snapshot);
                    }))(iterationParams));
                }
                else {
                    snapshots[i] = yield flowService.executeAction(this.snapshot.source, this.snapshot.wd, this.options.action, this.context, iterationParams, this.snapshot);
                }
            }
            yield Promise.all(promises);
            // register snapshots in the order of their presence
            snapshots.forEach(childSnapshot => {
                this.snapshot.registerChildActionSnapshot(childSnapshot);
            });
        });
    }
}
exports.RepeatFlowActionProcessor = RepeatFlowActionProcessor;
RepeatFlowActionProcessor.validationSchema = Joi.object({
    shareParameters: Joi.boolean(),
    times: Joi.number()
        .min(0)
        .required(),
    action: schemas_1.FBL_ACTION_SCHEMA,
    async: Joi.boolean(),
})
    .required()
    .options({ abortEarly: true });
class RepeatFlowActionHandler extends models_1.ActionHandler {
    /**
     * @inheritdoc
     */
    getMetadata() {
        return RepeatFlowActionHandler.metadata;
    }
    /**
     * @inheritdoc
     */
    getProcessor(options, context, snapshot, parameters) {
        return new RepeatFlowActionProcessor(options, context, snapshot, parameters);
    }
}
exports.RepeatFlowActionHandler = RepeatFlowActionHandler;
RepeatFlowActionHandler.metadata = {
    id: 'com.fireblink.fbl.flow.repeat',
    aliases: ['fbl.flow.repeat', 'flow.repeat', 'repeat'],
    // We don't want to process options as a template to avoid unexpected behaviour inside nested actions
    skipTemplateProcessing: true,
};
//# sourceMappingURL=RepeatFlowActionHandler.js.map