"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../../models");
const typedi_1 = require("typedi");
const Joi = require("joi");
const services_1 = require("../../services");
const schemas_1 = require("../../schemas");
const utils_1 = require("../../utils");
const errors_1 = require("../../errors");
class TryCatchFinallyFlowActionProcessor extends models_1.ActionProcessor {
    /**
     * @inheritdoc
     */
    getValidationSchema() {
        return TryCatchFinallyFlowActionProcessor.validationSchema;
    }
    /**
     * @inheritdoc
     */
    execute() {
        return __awaiter(this, void 0, void 0, function* () {
            const flowService = typedi_1.Container.get(services_1.FlowService);
            // run try
            let childSnapshot = yield flowService.executeAction(this.snapshot.source, this.snapshot.wd, this.options.action, this.context, this.parameters, this.snapshot);
            this.snapshot.ignoreChildFailure = true;
            this.snapshot.registerChildActionSnapshot(childSnapshot);
            if (!childSnapshot.successful && this.options.errorCode) {
                const code = childSnapshot.errorCode || errors_1.UNEXPECTED;
                utils_1.ContextUtil.assignTo(this.context, this.parameters, this.snapshot, this.options.errorCode.assignTo, code);
                utils_1.ContextUtil.pushTo(this.context, this.parameters, this.snapshot, this.options.errorCode.pushTo, code);
            }
            // run catch
            if (this.snapshot.childFailure && this.options.catch) {
                childSnapshot = yield flowService.executeAction(this.snapshot.source, this.snapshot.wd, this.options.catch, this.context, this.parameters, this.snapshot);
                this.snapshot.ignoreChildFailure = childSnapshot.successful;
                this.snapshot.registerChildActionSnapshot(childSnapshot);
            }
            // run finally
            if (this.options.finally) {
                childSnapshot = yield flowService.executeAction(this.snapshot.source, this.snapshot.wd, this.options.finally, this.context, this.parameters, this.snapshot);
                if (this.snapshot.ignoreChildFailure) {
                    this.snapshot.ignoreChildFailure = childSnapshot.successful;
                }
                this.snapshot.registerChildActionSnapshot(childSnapshot);
            }
        });
    }
}
exports.TryCatchFinallyFlowActionProcessor = TryCatchFinallyFlowActionProcessor;
TryCatchFinallyFlowActionProcessor.validationSchema = Joi.object({
    action: schemas_1.FBL_ACTION_SCHEMA,
    catch: schemas_1.FBL_ACTION_SCHEMA.optional(),
    finally: schemas_1.FBL_ACTION_SCHEMA.optional(),
    errorCode: Joi.object({
        assignTo: schemas_1.FBL_ASSIGN_TO_SCHEMA,
        pushTo: schemas_1.FBL_PUSH_TO_SCHEMA,
    }).options({ abortEarly: true, allowUnknown: false }),
})
    .required()
    .options({
    abortEarly: true,
    allowUnknown: false,
});
class TryCatchFinallyFlowActionHandler extends models_1.ActionHandler {
    /**
     * @inheritdoc
     */
    getMetadata() {
        return TryCatchFinallyFlowActionHandler.metadata;
    }
    /**
     * @inheritdoc
     */
    getProcessor(options, context, snapshot, parameters) {
        return new TryCatchFinallyFlowActionProcessor(options, context, snapshot, parameters);
    }
}
exports.TryCatchFinallyFlowActionHandler = TryCatchFinallyFlowActionHandler;
TryCatchFinallyFlowActionHandler.metadata = {
    id: 'com.fireblink.fbl.flow.try',
    aliases: ['fbl.flow.try', 'flow.try', 'try'],
    skipTemplateProcessing: true,
};
//# sourceMappingURL=TryCatchFinallyFlowActionHandler.js.map