"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../../models");
const Joi = require("joi");
const utils_1 = require("../../utils");
const BasePromptActionProcessor_1 = require("./BasePromptActionProcessor");
const schemas_1 = require("../../schemas");
class MultiSelectActionProcessor extends BasePromptActionProcessor_1.BasePromptActionProcessor {
    /**
     * @inheritdoc
     */
    getValidationSchema() {
        return MultiSelectActionProcessor.validationSchema;
    }
    /**
     * @inheritdoc
     */
    execute() {
        return __awaiter(this, void 0, void 0, function* () {
            const choices = this.options.options.map((o) => {
                let result;
                if (typeof o === 'string' || typeof o === 'number') {
                    result = {
                        title: o.toString(),
                        value: o,
                        selected: false,
                    };
                }
                else {
                    const obj = o;
                    result = {
                        title: obj.title,
                        value: obj.value,
                        selected: false,
                    };
                }
                let selected = false;
                if (this.options.default) {
                    selected = this.options.default.indexOf(result.value) >= 0;
                }
                result.selected = selected;
                return result;
            });
            const value = yield this.prompt({
                type: 'multiselect',
                choices: choices,
                message: this.options.message,
                max: this.options.max,
                hint: this.options.hint || '- Space to select. Return to submit',
            });
            /* istanbul ignore else */
            if (this.options.assignResponseTo) {
                utils_1.ContextUtil.assignTo(this.context, this.parameters, this.snapshot, this.options.assignResponseTo, value);
            }
            /* istanbul ignore else */
            if (this.options.pushResponseTo) {
                utils_1.ContextUtil.pushTo(this.context, this.parameters, this.snapshot, this.options.pushResponseTo, value);
            }
        });
    }
}
exports.MultiSelectActionProcessor = MultiSelectActionProcessor;
MultiSelectActionProcessor.validationSchema = Joi.object({
    message: Joi.string()
        .required()
        .min(1),
    options: Joi.array()
        .items(Joi.alternatives(Joi.string(), Joi.number()), Joi.object({
        title: Joi.string()
            .required()
            .min(1),
        value: Joi.any().required(),
    }))
        .min(1)
        .required(),
    default: Joi.array().items(Joi.alternatives(Joi.string(), Joi.number())),
    max: Joi.number(),
    hint: Joi.string(),
    assignResponseTo: schemas_1.FBL_ASSIGN_TO_SCHEMA,
    pushResponseTo: schemas_1.FBL_PUSH_TO_SCHEMA,
})
    .or('assignResponseTo', 'pushResponseTo')
    .required();
class MultiSelectActionHandler extends models_1.ActionHandler {
    /**
     * @inheritdoc
     */
    getMetadata() {
        return MultiSelectActionHandler.metadata;
    }
    /**
     * @inheritdoc
     */
    getProcessor(options, context, snapshot, parameters) {
        return new MultiSelectActionProcessor(options, context, snapshot, parameters);
    }
}
exports.MultiSelectActionHandler = MultiSelectActionHandler;
MultiSelectActionHandler.metadata = {
    id: 'com.fireblink.fbl.cli.prompts.multiselect',
    aliases: ['fbl.cli.prompts.multiselect', 'cli.prompts.multiselect', 'prompts.multiselect', 'multiselect'],
};
//# sourceMappingURL=MultiSelectActionHandler.js.map