"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
const typedi_1 = require("typedi");
const FBLService_1 = require("./FBLService");
const LogService_1 = require("./LogService");
let ActionHandlersRegistry = class ActionHandlersRegistry {
    constructor() {
        this.cleanup();
    }
    get logService() {
        return typedi_1.default.get(LogService_1.LogService);
    }
    /**
     * Register new entity
     * @param {ActionHandler} handler
     * @param {IPlugin} plugin
     * @param {ActionSnapshot} [snapshot]
     * @return self instance
     */
    register(handler, plugin, snapshot) {
        if (handler.getMetadata().aliases) {
            for (const alias of handler.getMetadata().aliases) {
                if (alias.startsWith(FBLService_1.FBLService.METADATA_PREFIX)) {
                    throw new Error(`Unable to register action handler with alias "${alias}". It can not start with ${FBLService_1.FBLService.METADATA_PREFIX}`);
                }
            }
        }
        if (handler.getMetadata().id.startsWith(FBLService_1.FBLService.METADATA_PREFIX)) {
            throw new Error(`Unable to register action handler with id "${handler.getMetadata().id}". It can not start with ${FBLService_1.FBLService.METADATA_PREFIX}`);
        }
        const metadata = handler.getMetadata();
        if (this.registry[metadata.id]) {
            if (snapshot) {
                snapshot.log(`Action handler with id ${metadata.id} was overridden by plugin ${plugin.name}@${plugin.version}`, true);
            }
            else {
                this.logService.error(' -> Warning'.red +
                    ' action handler with id: ' +
                    metadata.id.red +
                    ' was overridden by plugin ' +
                    `${plugin.name}@${plugin.version}`.red);
            }
        }
        this.registry[metadata.id] = handler;
        if (metadata.aliases) {
            metadata.aliases.forEach(alias => {
                if (this.aliases[alias]) {
                    /* istanbul ignore else */
                    if (snapshot) {
                        snapshot.log(`Action handler with alias ${alias} was overridden by plugin ${plugin.name}@${plugin.version}`, true);
                    }
                    else {
                        this.logService.error(' -> Warning'.red +
                            ' action handler with alias: ' +
                            alias.red +
                            ' was overridden by plugin ' +
                            `${plugin.name}@${plugin.version}`.red);
                    }
                }
                this.aliases[alias] = metadata.id;
            });
        }
        return this;
    }
    /**
     * Unregister handler by name
     * @param {string} id
     * @return self instance
     */
    unregister(id) {
        delete this.registry[id];
        Object.keys(this.aliases).forEach(key => {
            if (this.aliases[key] === id) {
                delete this.aliases[key];
            }
        });
        return this;
    }
    cleanup() {
        this.registry = {};
        this.aliases = {};
        return this;
    }
    /**
     * Find action handler by id or alias
     * @param {string} idOrAlias
     */
    find(idOrAlias) {
        let actionHandler = this.registry[idOrAlias];
        if (!actionHandler) {
            const id = this.aliases[idOrAlias];
            if (id) {
                actionHandler = this.registry[id];
            }
        }
        if (!actionHandler) {
            return null;
        }
        return actionHandler;
    }
};
ActionHandlersRegistry = __decorate([
    typedi_1.Service(),
    __metadata("design:paramtypes", [])
], ActionHandlersRegistry);
exports.ActionHandlersRegistry = ActionHandlersRegistry;
//# sourceMappingURL=ActionHandlersRegistry.js.map